mysql.exceptions.server.Server_Is_In_Secure_Auth_Mode

Package mysql :: Package exceptions :: Module server :: Class Server_Is_In_Secure_Auth_Mode |
[hide private]
[frames] | no frames]

# Class Server_Is_In_Secure_Auth_Mode

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                base.MySQL_Error --+
                                   |
                                  Server_Is_In_Secure_Auth_Mode

Server is running in --secure-auth mode, but '%s'@'%s' has a password in the old format; please change the password to the new format

Instance Methods | [hide private]
Inherited from `base.MySQL_Error`: `__init__`, `__repr__`, `__str__` Inherited from `exceptions.Exception`: `__getitem__`

Instance Variables | [hide private]
Inherited from `base.MySQL_Error`: `errno`, `error_string`